@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Array;
-$List::Objects::WithUtils::Role::Array::VERSION = '2.028001';
+$List::Objects::WithUtils::Role::Array::VERSION = '2.028002';
 use strictures 2;
 
 use Carp            ();
@@ -475,25 +475,25 @@ sub ssect {
 sub tuples {
   my ($self, $size, $type, $bless) = @_;
   $size = 2 unless defined $size;
-  my $cls = blessed_or_pkg($self);
-  if (defined $type) {
-    # Autoboxed? Need to be blessed if we're to _try_coerce
-    $self = $cls->new(@$self) unless Scalar::Util::blessed $self;
-  }
   Carp::confess "Expected a positive integer size but got $size"
     if $size < 1;
+
+  # Autoboxed? Need to be blessed if we're to _try_coerce:
+  my $cls = blessed_or_pkg($self);
+  $self = $cls->new(@$self)
+    if defined $type and not Scalar::Util::blessed $self;
+
   my $itr = do {
     my @copy = @$self;
     sub { CORE::splice @copy, 0, $size }
   };
   my @res;
   while (my @nxt = $itr->()) {
-    if (defined $type) {
-      @nxt = CORE::map {; $self->_try_coerce($type, $_) }
-        @nxt[0 .. ($size-1)]
-    }
+    @nxt = CORE::map {; $self->_try_coerce($type, $_) } @nxt
+      if defined $type;
     CORE::push @res, $bless ? $cls->new(@nxt) : [ @nxt ];
   }
+
   $cls->new(@res)
 }
 
@@ -603,6 +603,7 @@ sub shuffle {
 
 { no warnings 'once'; *squish = *squished; }
 sub squished {
+  # @last is a single-item array to make tracking undefs saner ->
   my (@last, @res);
   ITEM: for (@{ $_[0] }) {
     if (!@last) {
@@ -993,11 +994,11 @@ Returns the array element corresponding to a specified index.
 
 =head3 get_or_else
 
-  # Expect to find a hash() obj at $pos in $array,
-  # or create an empty one if $pos is undef:
+  # Expect to find an object at $pos in $array,
+  # or return an empty one if $pos is undef:
   my @keys = $array->get_or_else($pos => hash)->keys->all;
 
-  # Or pass a coderef
+  # Or pass a coderef that provides a default return value;
   # First arg is the object being operated on:
   my $item_or_first = $array->get_or_else($pos => sub { shift->get(0) });
   # Second arg is the requested index:
@@ -1009,11 +1010,11 @@ Returns the array element corresponding to a specified index.
   });
 
 Returns the element corresponding to a specified index; optionally takes a
-second argument that is used as a default value if the given index is undef.
+second argument that is used as a default return value if the given index is
+undef (the array remains unmodified).
 
 If the second argument is a coderef, it is invoked on the object (with the
-requested index as an argument) and its return value is taken as the default
-value.
+requested index as an argument) and its return value is taken as the default.
 
 =head3 head
 
@@ -1042,9 +1043,9 @@ Defaults to ',' if no delimiter is specified.
 
 =head3 kv
 
-Returns an array-type object containing key/value pairs as (unblessed) ARRAYs;
+Returns an array-type object containing index/value pairs as (unblessed) ARRAYs;
 this is much like L<List::Objects::WithUtils::Role::Hash/"kv">, except the
-array index is the key.
+array index is the "key."
 
 =head3 zip
 
@@ -1177,7 +1178,7 @@ of the specified size (defaults to 2).
 
 C<tuples> accepts L<Type::Tiny> types as an optional second parameter; if
 specified, items in tuples are checked against the type and a coercion is
-attempted if the initial type-check fails:
+attempted (if available for the given type) if the initial type-check fails:
 
   use Types::Standard -all;
   my $tuples = array(1 .. 7)->tuples(2 => Int);
