@@ -1,5 +1,5 @@
 package List::Objects::WithUtils::Role::Hash;
-$List::Objects::WithUtils::Role::Hash::VERSION = '2.028001';
+$List::Objects::WithUtils::Role::Hash::VERSION = '2.028002';
 use strictures 2;
 
 use Module::Runtime ();
@@ -124,9 +124,7 @@ sub get_path {
 sub set {
   my $self = shift;
   my (@keysidx, @valsidx);
-  for (0 .. $#_) {
-    $_ % 2 ? push @valsidx, $_ : push @keysidx, $_
-  }
+  $_ % 2 ? push @valsidx, $_ : push @keysidx, $_ for 0 .. $#_;
   @{$self}{ @_[@keysidx] } = @_[@valsidx];
   $self
 }
@@ -245,11 +243,11 @@ sub inverted {
 
 sub random_kv {
   my $key = (CORE::keys %{ $_[0] })[rand CORE::keys %{ $_[0] }];
-  $key ? [ $key => $_[0]->{$key} ] : ()
+  $key ? [ $key => $_[0]->{$key} ] : undef
 }
 
 sub random_key {
-  (CORE::keys %{ $_[0] })[rand CORE::keys %{ $_[0] }]
+  (CORE::keys %{ $_[0] })[rand (CORE::keys %{ $_[0] } || return undef)]
 }
 
 sub random_value {
@@ -355,7 +353,8 @@ objects.
   my $obj = hash(foo => 'bar', baz => 'quux')->inflate;
   my $baz = $obj->baz; 
 
-Inflates a simple object providing accessors for a hash.
+Inflates the hash-type object into a simple struct-like object with accessor
+methods matching the keys of the hash.
 
 By default, accessors are read-only; specifying C<rw => 1> allows setting new
 values:
@@ -374,14 +373,14 @@ for modification:
 
 =head3 inflated_type
 
-The class name that objects are blessed into when calling L</inflate>.
+The class that objects are blessed into when calling L</inflate>.
 
 Defaults to L<List::Objects::WithUtils::Hash::Inflated>.
 
 =head3 inflated_rw_type
 
-The class name that objects are blessed into when calling L</inflate> with
-C<rw => 1>.
+The class that objects are blessed into when calling L</inflate> with
+C<rw => 1> specified.
 
 Defaults to L<List::Objects::WithUtils::Hash::Inflated::RW>, a subclass of
 L<List::Objects::WithUtils::Hash::Inflated>.
@@ -449,7 +448,7 @@ Returns the current hash object.
 
 Retrieves a key or list of keys from the hash.
 
-If we're taking a slice (multiple keys were specified), values are returned
+If taking a slice (multiple keys were specified), values are returned
 as an L</array_type> object. (See L</sliced> if you'd rather generate a new
 hash.)
 
@@ -524,10 +523,12 @@ Returns the list of values in the hash as an L</array_type> object.
   #   3 => array('d'),
   # }
 
-Inverts the hash, creating L</array_type> objects containing one or more keys
-for each unique value.
+Inverts the hash; the values of the original hash become keys in the new
+object. Their corresponding values are L</array_type> objects containing the
+key(s) that mapped to the original value.
 
-This is a bit like reversing the hash, but lossless.
+This is a bit like reversing the hash, but lossless with regards to non-unique
+values.
 
 (Available from v2.14.1)
 
@@ -539,9 +540,10 @@ This is a bit like reversing the hash, but lossless.
   }
 
 Returns an iterator that, when called, returns ($key, $value) pairs.
+When the list is exhausted, an empty list is returned.
 
-The iterator operates on a shallow clone of the current hash, making it
-(relatively) safe to operate on the original hash while using the iterator.
+The iterator operates on a shallow clone of the hash, making it safe to
+operate on the original hash while using the iterator.
 
 (Available from v2.9.1)
 
@@ -575,10 +577,8 @@ Like C<map>, but operates on pairs. See L<List::Util/"pairmap">.
 
 Returns an L</array_type> object containing the results of the map.
 
-In versions prior to v2.20.1, C<$_[0]> and C<$_[1]> must be used in place of
-C<$a> and C<$b>, respectively.
-
-(Available from v2.8.1)
+(Available from v2.8.1; in versions prior to v2.20.1, C<$_[0]> and C<$_[1]>
+must be used in place of C<$a> and C<$b>, respectively.)
 
 =head3 kv_sort
 
@@ -602,18 +602,24 @@ C<$a> and C<$b>, respectively.
 
 Returns a random key/value pair from the hash as an C<ARRAY>-type reference.
 
+Returns undef if the hash is empty.
+
 (Available from v2.28.1)
 
 =head3 random_key
 
 Returns a random key from the hash.
 
+Returns undef if the hash is empty.
+
 (Available from v2.28.1)
 
 =head3 random_value
 
 Returns a random value from the hash.
 
+Returns undef if the hash is empty.
+
 (Available from v2.28.1)
 
 =head3 sliced
